@@ -7,7 +7,7 @@
 #include <QTimer>
 #endif
 
-ClipboardMonitor::ClipboardMonitor* monitorInstance = 0;
+ClipboardMonitor* ClipboardMonitor::m_instance = 0;
 
 ClipboardMonitor::ClipboardMonitor(QObject *parent) :
     QObject(parent)
@@ -15,15 +15,15 @@ ClipboardMonitor::ClipboardMonitor(QObject *parent) :
   ,m_timer(0)
   #endif
 {
-    if (!monitorInstance) {
-        monitorInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 
     this->connect(QApplication::clipboard(), SIGNAL(dataChanged()), this, SLOT(onClipboardTextChanged()));
 }
 
 ClipboardMonitor* ClipboardMonitor::instance() {
-    return monitorInstance;
+    return !m_instance ? new ClipboardMonitor : m_instance;
 }
 
 void ClipboardMonitor::onClipboardTextChanged() {
