@@ -12,7 +12,7 @@
 #include <QDebug>
 #include <QThread>
 
-Database::Database* databaseInstance = 0;
+Database* Database::m_instance = 0;
 
 Database::Database() :
     QObject(),
@@ -21,8 +21,8 @@ Database::Database() :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!databaseInstance) {
-        databaseInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 
     this->moveToThread(m_thread);
@@ -49,7 +49,7 @@ Database::~Database() {
 }
 
 Database* Database::instance() {
-    return databaseInstance;
+    return !m_instance ? new Database : m_instance;
 }
 
 void Database::initialize() {
