@@ -4,11 +4,12 @@
 #include "enums.h"
 #include <QAbstractListModel>
 #include <QUrl>
+#include <QString>
 
 typedef struct {
     Queries::QueryType type;
     QUrl feed;
-    QString title;
+    QString name;
 } ExploreItem;
 
 class ExploreModel : public QAbstractListModel
@@ -21,7 +22,7 @@ class ExploreModel : public QAbstractListModel
 
 public:
     enum Roles {
-        TitleRole = Qt::DisplayRole,
+        NameRole = Qt::DisplayRole,
         TypeRole = Qt::UserRole + 1,
         FeedRole
 
@@ -34,7 +35,7 @@ public:
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
 
 private:
-    void addItem(Queries::QueryType type, const QUrl &feed, const QString &title);
+    void addItem(Queries::QueryType type, const QUrl &feed, const QString &name);
     
 signals:
     void countChanged(int count);
