@@ -2,6 +2,8 @@
 #define HOMESCREENMODEL_H
 
 #include <QAbstractListModel>
+#include <QPair>
+#include <QString>
 
 class HomescreenModel : public QAbstractListModel
 {
