@@ -13,21 +13,21 @@
 const QString API_KEY("ac4c4586cc1441c74011bf89b28af6b3");
 const QString API_SECRET("05e69588c52c6da942f56d3faed3c45f");
 
-Lastfm::Lastfm *lastfmInstance = 0;
+Lastfm* Lastfm::m_instance = 0;
 
 Lastfm::Lastfm(QObject *parent) :
     QObject(parent),
     m_nam(0)
 {
-    if (!lastfmInstance) {
-        lastfmInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 }
 
 Lastfm::~Lastfm() {}
 
 Lastfm* Lastfm::instance() {
-    return lastfmInstance;
+    return !m_instance ? new Lastfm : m_instance;
 }
 
 void Lastfm::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
