@@ -7,16 +7,20 @@
 #include "lastfm.h"
 #include "database.h"
 #include "utils.h"
+#ifdef SYMBIAN_OS
+#include <QNetworkAccessManager>
+#include <QNetworkConfiguration>
+#endif
 
-MediaPlayer::MediaPlayer* mediaplayerInstance = 0;
+MediaPlayer* MediaPlayer::m_instance = 0;
 
 MediaPlayer::MediaPlayer(QObject *parent) :
     QMediaPlayer(parent),
     m_index(0),
     m_playbackMode(PlaybackMode::Sequential)
 {
-    if (!mediaplayerInstance) {
-        mediaplayerInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 
     this->connect(this, SIGNAL(stateChanged(QMediaPlayer::State)), this, SLOT(onStateChanged(QMediaPlayer::State)));
@@ -38,7 +42,7 @@ MediaPlayer::MediaPlayer(QObject *parent) :
 MediaPlayer::~MediaPlayer() {}
 
 MediaPlayer* MediaPlayer::instance() {
-    return !mediaplayerInstance ? new MediaPlayer(Session::instance()) : mediaplayerInstance;
+    return !m_instance ? new MediaPlayer(Session::instance()) : m_instance;
 }
 
 #ifdef QML_USER_INTERFACE
@@ -121,6 +125,9 @@ void MediaPlayer::setCurrentIndex(int index, bool playImmediately) {
 }
 
 void MediaPlayer::play(bool resetSource) {
+#ifdef SYMBIAN_OS
+    this->setNetworkConfigurations(QList<QNetworkConfiguration>() << Session::instance()->networkAccessManager()->activeConfiguration());
+#endif
     if (((this->media().isNull()) || (resetSource)) && (!this->currentTrack().isNull())) {
         switch (this->currentTrack().data()->service()) {
         case Services::NoService:
@@ -247,11 +254,24 @@ void MediaPlayer::onError(QMediaPlayer::Error error) {
     switch (error) {
     case NoError:
         return;
+    case ResourceError:
+        Notifications::instance()->onError(QString("%1: %2").arg(tr("Playback error")).arg(tr("Cannot find resource")));
+        break;
+    case FormatError:
+        Notifications::instance()->onError(QString("%1: %2").arg(tr("Playback error")).arg(tr("Format not supported")));
+        break;
+    case NetworkError:
+        Notifications::instance()->onError(QString("%1: %2").arg(tr("Playback error")).arg(tr("Network error")));
+        break;
+    case AccessDeniedError:
+        Notifications::instance()->onError(QString("%1: %2").arg(tr("Playback error")).arg(tr("Access to the resource has been denied")));
+        break;
     default:
-        this->setMedia(QMediaContent());
         Notifications::instance()->onError(this->errorString());
-        return;
+        break;
     }
+
+    this->setMedia(QMediaContent());
 }
 
 #ifdef MEDIA_PLAYERS_ENABLED
