@@ -3,12 +3,13 @@
 #ifndef QML_USER_INTERFACE
 #include <QProgressDialog>
 #ifdef Q_WS_MAEMO_5
-#include "windowstack.h"
+#include "../maemo5/windowstack.h"
+#include "../maemo5/stackedwindow.h"
 #include <QMaemo5InformationBox>
 #endif
 #endif
 
-Notifications::Notifications* notificationsInstance = 0;
+Notifications* Notifications::m_instance = 0;
 
 Notifications::Notifications(QObject *parent) :
     QObject(parent)
@@ -16,13 +17,13 @@ Notifications::Notifications(QObject *parent) :
     ,m_progressDialog(0)
   #endif
 {
-    if (!notificationsInstance) {
-        notificationsInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 }
 
 Notifications* Notifications::instance() {
-    return notificationsInstance;
+    return !m_instance ? new Notifications : m_instance;
 }
 
 #ifdef Q_WS_MAEMO_5
