@@ -4,7 +4,7 @@
 #include "thumbnailcache.h"
 #endif
 
-PlaybackListModel::PlaybackListModel* queue = 0;
+PlaybackListModel* PlaybackListModel::m_queue = 0;
 
 PlaybackListModel::PlaybackListModel(QObject *parent) :
     QAbstractListModel(parent)
@@ -13,8 +13,8 @@ PlaybackListModel::PlaybackListModel(QObject *parent) :
     m_thumbnailPressedRow(-1)
   #endif
 {
-    if (!queue) {
-        queue = this;
+    if (!m_queue) {
+        m_queue = this;
     }
 
     QHash<int, QByteArray> roles;
@@ -48,7 +48,7 @@ PlaybackListModel::~PlaybackListModel() {
 }
 
 PlaybackListModel* PlaybackListModel::playbackQueue() {
-    return queue;
+    return !m_queue ? new PlaybackListModel : m_queue;
 }
 
 void PlaybackListModel::clear() {
