@@ -10,7 +10,7 @@
 #ifndef QML_USER_INTERFACE
 #include "thumbnailcache.h"
 #ifdef Q_WS_MAEMO_5
-#include "windowstack.h"
+#include "../maemo5/windowstack.h"
 #endif
 #endif
 #if (defined (MEDIA_PLAYERS_ENABLED)) && (defined (QML_USER_INTERFACE))
@@ -18,7 +18,7 @@
 #endif
 #include <QNetworkAccessManager>
 
-Session::Session* sessionInstance = 0;
+Session* Session::m_instance = 0;
 
 Session::Session(QObject *parent) :
     QObject(parent),
@@ -41,8 +41,8 @@ Session::Session(QObject *parent) :
   #endif
   #endif
 {
-    if (!sessionInstance) {
-        sessionInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 
     this->connect(m_soundcloud, SIGNAL(signedIn(QString)), m_database, SLOT(storeSoundCloudToken(QString)));
@@ -107,5 +107,5 @@ Session::~Session() {
 }
 
 Session* Session::instance() {
-    return sessionInstance;
+    return !m_instance ? new Session : m_instance;
 }
