@@ -2,7 +2,7 @@
 #include <QDir>
 #include <QDesktopServices>
 
-Settings::Settings* settingsInstance = 0;
+Settings* Settings::m_instance = 0;
 
 Settings::Settings(QObject *parent) :
     QSettings(QString("MusiKloud"), QString("MusiKloud"), parent),
@@ -29,8 +29,8 @@ Settings::Settings(QObject *parent) :
     m_eventFeedInstalled(false)
   #endif
 {
-    if (!settingsInstance) {
-        settingsInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 }
 
@@ -39,7 +39,7 @@ Settings::~Settings() {
 }
 
 Settings* Settings::instance() {
-    return settingsInstance;
+    return !m_instance ? new Settings : m_instance;
 }
 
 void Settings::restoreSettings() {
