@@ -17,7 +17,7 @@ const QString CLIENT_ID("aada80a82c91fb42d0bb1cb321b59034");
 const QString CLIENT_SECRET("dcc9c80ce05614d4988cebb82ddde152");
 const QString REDIRECT_URI("http://www.musikloud.co.uk");
 
-SoundCloud::SoundCloud* soundCloudInstance = 0;
+SoundCloud* SoundCloud::m_instance = 0;
 
 using namespace QtJson;
 
@@ -27,15 +27,15 @@ SoundCloud::SoundCloud(QObject *parent) :
     m_busy(false),
     m_cancelled(false)
 {
-    if (!soundCloudInstance) {
-        soundCloudInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 }
 
 SoundCloud::~SoundCloud() {}
 
 SoundCloud* SoundCloud::instance() {
-    return soundCloudInstance;
+    return !m_instance ? new SoundCloud : m_instance;
 }
 
 void SoundCloud::setBusy(bool isBusy, const QString &message, int numberOfOperations) {
@@ -155,8 +155,9 @@ QUrl SoundCloud::getStreamUrl(QUrl url) {
     if (url.scheme() == "https") {
         url.setScheme("http");
     }
-
-    url.addQueryItem("client_id", CLIENT_ID);
+    if (!url.hasQueryItem("client_id")) {
+        url.addQueryItem("client_id", CLIENT_ID);
+    }
 
     return url;
 }
