@@ -62,7 +62,7 @@ TrackItem::TrackItem(const QVariantMap &track, QObject *parent) :
     QObject(parent),
     m_id(track.value("id").toString()),
     m_url(track.value("url").toUrl()),
-    m_streamUrl(track.value("stream_url").toUrl()),
+    m_streamUrl(QUrl(QString("http://api.soundcloud.com/tracks/%1/stream?client_id=b45b1aa10f1ac2941910a7f0d10f8e28").arg(this->id()))),
     m_downloadUrl(track.value("download_url").toUrl()),
     m_embedUrl(track.value("embed_url").toUrl()),
     m_title(track.value("title").toString()),
