@@ -11,11 +11,15 @@ class TrackLauncher : public QObject
 public:
     explicit TrackLauncher(QObject *parent = 0);
     ~TrackLauncher();
+
     static TrackLauncher* instance();
     
 public slots:
     static void launchTrack(const QUrl &url);
     static void launchTracks(QList<QUrl> &urls);
+
+private:
+    static TrackLauncher* m_instance;
 };
 
 #endif // TRACKLAUNCHER_H
