@@ -4,7 +4,7 @@
 #include "trackitem.h"
 #include "playlistitem.h"
 
-TransferManager::TransferManager* managerInstance = 0;
+TransferManager* TransferManager::m_instance = 0;
 
 TransferManager::TransferManager(QObject *parent) :
     QObject(parent),
@@ -14,8 +14,8 @@ TransferManager::TransferManager(QObject *parent) :
   ,m_transferUI(new Client(this))
   #endif
 {
-    if (!managerInstance) {
-        managerInstance = this;
+    if (!m_instance) {
+        m_instance = this;
     }
 #ifdef MEEGO_EDITION_HARMATTAN
     m_transferUI->init();
@@ -29,7 +29,7 @@ TransferManager::~TransferManager() {
 }
 
 TransferManager* TransferManager::instance() {
-    return managerInstance;
+    return !m_instance ? new TransferManager : m_instance;
 }
 
 void TransferManager::restoreStoredDownloads() {
