@@ -25,7 +25,7 @@ ExploreDialog::ExploreDialog(QWidget *parent) :
 
 void ExploreDialog::onCategoryChosen(const QModelIndex &index) {
     emit categoryChosen(static_cast<Queries::QueryType>(index.data(ExploreModel::TypeRole).toInt()),
-                        index.data(ExploreModel::TitleRole).toString(),
+                        index.data(ExploreModel::NameRole).toString(),
                         index.data(ExploreModel::FeedRole).toUrl());
     this->accept();
 }
