@@ -19,9 +19,10 @@
 #include "nowplayingwindow.h"
 #include "channelwindow.h"
 #include "navbutton.h"
+#include "nowplayingbutton.h"
 #include "../base/feedurls.h"
 #include "../base/soundcloud.h"
-#include "../base/windowstack.h"
+#include "windowstack.h"
 #include "../base/settings.h"
 #include "../base/clipboardmonitor.h"
 #include "../base/mediaplayer.h"
@@ -42,6 +43,7 @@ HomeWindow::HomeWindow(QWidget *parent) :
     m_archiveButton(new NavButton(tr("Archive"), ":/images/archive.png", this)),
     m_accountsButton(new NavButton(tr("Accounts"), ":/images/accounts.png", this)),
     m_settingsButton(new NavButton(tr("Settings"), ":/images/settings.png", this)),
+    m_nowPlayingButton(0),
     m_settingsAction(this->menuBar()->addAction(tr("Settings"), this, SLOT(showSettingsDialog()))),
     m_aboutAction(this->menuBar()->addAction(tr("About"), this, SLOT(showAboutDialog()))),
     m_grid(0)
@@ -63,6 +65,7 @@ HomeWindow::HomeWindow(QWidget *parent) :
     this->connect(m_settingsButton, SIGNAL(clicked()), this, SLOT(showSettingsDialog()));
     this->connect(ClipboardMonitor::instance(), SIGNAL(gotClipboardUrl(QString)), this, SLOT(displayResource(QString)));
 
+    this->onMediaPlayerChanged(Settings::instance()->mediaPlayer());
     this->onOrientationChanged();
 }
 
@@ -215,7 +218,7 @@ void HomeWindow::showSearchDialog() {
     dialog->open();
 
     this->connect(dialog, SIGNAL(search(QString,Queries::QueryType,Queries::QueryOrder)), this, SLOT(search(QString,Queries::QueryType,Queries::QueryOrder)));
-    this->connect(dialog, SIGNAL(fromUrl(QString)), this, SLOT(getResourceFromUrl(QString)));
+    this->connect(dialog, SIGNAL(fromUrl(QString)), this, SLOT(displayResource(QString)));
 }
 
 void HomeWindow::search(const QString &query, Queries::QueryType type, Queries::QueryOrder order) {
@@ -404,3 +407,17 @@ void HomeWindow::showSignInDialog() {
 
     this->connect(dialog, SIGNAL(accepted()), this, SLOT(showAccountsDialog()));
 }
+
+void HomeWindow::onMediaPlayerChanged(const QString &mediaPlayer) {
+    if (mediaPlayer == "musikloud") {
+        if (!m_nowPlayingButton) {
+            m_nowPlayingButton = new NowPlayingButton(this);
+        }
+
+        m_nowPlayingButton->poke();
+    }
+    else if (m_nowPlayingButton) {
+        m_nowPlayingButton->deleteLater();
+        m_nowPlayingButton = 0;
+    }
+}
