@@ -2,6 +2,7 @@
 #include "thumbnaillabel.h"
 #include "mediaplayerbutton.h"
 #include "nowplayingdelegate.h"
+#include "screen.h"
 #include "../base/playbacklistmodel.h"
 #include "../base/thumbnailcache.h"
 #include "../base/mediaplayer.h"
@@ -78,10 +79,21 @@ NowPlayingMediaTab::NowPlayingMediaTab(QWidget *parent) :
     this->connect(m_thumbnailLabel, SIGNAL(clicked()), this, SLOT(onThumbnailClicked()));
     this->connect(m_progressSlider, SIGNAL(sliderReleased()), this, SLOT(onSliderReleased()));
     this->connect(PlaybackListModel::playbackQueue(), SIGNAL(countChanged(int)), this, SLOT(onCountChanged(int)));
+    this->connect(Screen::instance(), SIGNAL(screenLockStateChanged(bool)), this, SLOT(onScreenLockStateChanged(bool)));
 
     this->onOrientationChanged();
 }
 
+void NowPlayingMediaTab::showEvent(QShowEvent *event) {
+    this->connectPlaybackSignals();
+    event->accept();
+}
+
+void NowPlayingMediaTab::hideEvent(QHideEvent *event) {
+    this->disconnectPlaybackSignals();
+    event->accept();
+}
+
 void NowPlayingMediaTab::setLandscapeLayout() {
     m_thumbnailLabel->move(30, 30);
     m_container->setGeometry(345, 0, 445, 354);
@@ -96,6 +108,25 @@ void NowPlayingMediaTab::setPortraitLayout() {
     m_toolBar->setGeometry(0, 674, 480, 70);
 }
 
+void NowPlayingMediaTab::connectPlaybackSignals() {
+    this->connect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPositionChanged(qint64)));
+    this->connect(MediaPlayer::instance(), SIGNAL(durationChanged(qint64)), this, SLOT(onDurationChanged(qint64)));
+    this->connect(MediaPlayer::instance(), SIGNAL(currentIndexChanged(int)), this, SLOT(onCurrentIndexChanged(int)));
+    this->connect(MediaPlayer::instance(), SIGNAL(currentTrackChanged(QSharedPointer<TrackItem>)), this, SLOT(onCurrentTrackChanged(QSharedPointer<TrackItem>)));
+
+    this->onPositionChanged(MediaPlayer::instance()->position());
+    this->onDurationChanged(MediaPlayer::instance()->duration());
+    this->onCurrentIndexChanged(MediaPlayer::instance()->currentIndex());
+    this->onCurrentTrackChanged(MediaPlayer::instance()->currentTrack());
+}
+
+void NowPlayingMediaTab::disconnectPlaybackSignals() {
+    this->disconnect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPositionChanged(qint64)));
+    this->disconnect(MediaPlayer::instance(), SIGNAL(durationChanged(qint64)), this, SLOT(onDurationChanged(qint64)));
+    this->disconnect(MediaPlayer::instance(), SIGNAL(currentIndexChanged(int)), this, SLOT(onCurrentIndexChanged(int)));
+    this->disconnect(MediaPlayer::instance(), SIGNAL(currentTrackChanged(QSharedPointer<TrackItem>)), this, SLOT(onCurrentTrackChanged(QSharedPointer<TrackItem>)));
+}
+
 void NowPlayingMediaTab::setThumbnail() {
     if (MediaPlayer::instance()->currentTrack().isNull()) {
         return;
@@ -164,6 +195,15 @@ void NowPlayingMediaTab::onCurrentTrackChanged(QSharedPointer<TrackItem> track)
     }
 }
 
+void NowPlayingMediaTab::onScreenLockStateChanged(bool locked) {
+    if (locked) {
+        this->disconnectPlaybackSignals();
+    }
+    else if (this->isVisible()) {
+        this->connectPlaybackSignals();
+    }
+}
+
 void NowPlayingMediaTab::showContextMenu(const QPoint &pos) {
     m_contextMenu->popup(pos, m_deleteAction);
 }
@@ -176,26 +216,3 @@ void NowPlayingMediaTab::onItemClicked(const QModelIndex &index) {
 void NowPlayingMediaTab::deleteTrackFromQueue() {
     PlaybackListModel::playbackQueue()->removeTrack(m_view->currentIndex().row());
 }
-
-void NowPlayingMediaTab::showEvent(QShowEvent *event) {
-    this->connect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPositionChanged(qint64)));
-    this->connect(MediaPlayer::instance(), SIGNAL(durationChanged(qint64)), this, SLOT(onDurationChanged(qint64)));
-    this->connect(MediaPlayer::instance(), SIGNAL(currentIndexChanged(int)), this, SLOT(onCurrentIndexChanged(int)));
-    this->connect(MediaPlayer::instance(), SIGNAL(currentTrackChanged(QSharedPointer<TrackItem>)), this, SLOT(onCurrentTrackChanged(QSharedPointer<TrackItem>)));
-
-    this->onPositionChanged(MediaPlayer::instance()->position());
-    this->onDurationChanged(MediaPlayer::instance()->duration());
-    this->onCurrentIndexChanged(MediaPlayer::instance()->currentIndex());
-    this->onCurrentTrackChanged(MediaPlayer::instance()->currentTrack());
-
-    event->accept();
-}
-
-void NowPlayingMediaTab::hideEvent(QHideEvent *event) {
-    this->disconnect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(onPositionChanged(qint64)));
-    this->disconnect(MediaPlayer::instance(), SIGNAL(durationChanged(qint64)), this, SLOT(onDurationChanged(qint64)));
-    this->disconnect(MediaPlayer::instance(), SIGNAL(currentIndexChanged(int)), this, SLOT(onCurrentIndexChanged(int)));
-    this->disconnect(MediaPlayer::instance(), SIGNAL(currentTrackChanged(QSharedPointer<TrackItem>)), this, SLOT(onCurrentTrackChanged(QSharedPointer<TrackItem>)));
-
-    event->accept();
-}
