@@ -4,6 +4,11 @@
 #include "channelwindow.h"
 #include "trackselectionwindow.h"
 #include "nowplayingwindow.h"
+#include "listview.h"
+#include "thumbnaillabel.h"
+#include "separatorlabel.h"
+#include "nowplayingbutton.h"
+#include "scrollarea.h"
 #include "../base/tracklistmodel.h"
 #include "../base/thumbnailcache.h"
 #include "../base/playlistitem.h"
@@ -13,12 +18,8 @@
 #include "../base/soundcloud.h"
 #include "../base/tracklauncher.h"
 #include "../base/mediaplayer.h"
-#include "listview.h"
-#include "thumbnaillabel.h"
-#include "separatorlabel.h"
 #include <QAction>
 #include <QLabel>
-#include <QScrollArea>
 #include <QPushButton>
 #include <QMenuBar>
 #include <QGridLayout>
@@ -46,7 +47,7 @@ PlaylistTracksWindow::PlaylistTracksWindow(QSharedPointer<PlaylistItem> playlist
     m_playButton(new QPushButton(tr("Play all"), this)),
     m_separator1(new SeparatorLabel(tr("Description"), this)),
     m_separator2(new SeparatorLabel(QString("-- %1").arg(tr("tracks")), this)),
-    m_scrollArea(new QScrollArea(this))
+    m_scrollArea(new ScrollArea(this))
 {
     this->setWindowTitle(tr("Set"));
     this->setCentralWidget(m_scrollArea);
@@ -55,6 +56,7 @@ PlaylistTracksWindow::PlaylistTracksWindow(QSharedPointer<PlaylistItem> playlist
 
     m_listView->setModel(m_model);
     m_listView->setItemDelegate(delegate);
+    m_listView->setMonitorScrolling(true);
     m_titleLabel->setWordWrap(true);
     m_descriptionLabel->setWordWrap(true);
 
@@ -80,6 +82,7 @@ PlaylistTracksWindow::PlaylistTracksWindow(QSharedPointer<PlaylistItem> playlist
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_scrollArea->setMonitorScrolling(true);
 
     this->connect(m_model, SIGNAL(loadingChanged(bool)), this, SLOT(onLoadingChanged(bool)));
     this->connect(m_model, SIGNAL(countChanged(int)), this, SLOT(onCountChanged(int)));
@@ -89,6 +92,11 @@ PlaylistTracksWindow::PlaylistTracksWindow(QSharedPointer<PlaylistItem> playlist
     this->connect(m_listView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(showContextMenu(QPoint)));
     this->connect(m_playButton, SIGNAL(clicked()), this, SLOT(playPlaylist()));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_scrollArea, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_scrollArea, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     m_model->getPlaylistTracks(m_playlist.data()->id());
 
     this->setThumbnail();
