@@ -7,6 +7,8 @@
 #include "commentdialog.h"
 #include "sharingdialog.h"
 #include "channelwindow.h"
+#include "nowplayingbutton.h"
+#include "scrollarea.h"
 #include "../base/commentlistmodel.h"
 #include "../base/soundcloud.h"
 #include "../base/tracklauncher.h"
@@ -19,7 +21,6 @@
 #include <QMenuBar>
 #include <QGridLayout>
 #include <QLabel>
-#include <QScrollArea>
 #include <QAction>
 
 TrackInfoWindow::TrackInfoWindow(QSharedPointer<TrackItem> track, QWidget *parent) :
@@ -47,7 +48,7 @@ TrackInfoWindow::TrackInfoWindow(QSharedPointer<TrackItem> track, QWidget *paren
     m_commentsSeparator(new SeparatorLabel(tr("Comments"), this)),
     m_commentsModel(new CommentListModel(this)),
     m_commentsView(new ListView(this)),
-    m_scrollArea(new QScrollArea(this))
+    m_scrollArea(new ScrollArea(this))
 {
     this->setWindowTitle(tr("Track info"));
     this->setCentralWidget(m_scrollArea);
@@ -87,6 +88,7 @@ TrackInfoWindow::TrackInfoWindow(QSharedPointer<TrackItem> track, QWidget *paren
     m_scrollArea->setWidgetResizable(true);
     m_scrollArea->setWidget(scrollWidget);
     m_scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    m_scrollArea->setMonitorScrolling(true);
 
     this->connect(m_commentsModel, SIGNAL(countChanged(int)), this, SLOT(onCommentsCountChanged(int)));
     this->connect(delegate, SIGNAL(showUserChannel(QModelIndex)), this, SLOT(showUserChannel(QModelIndex)));
@@ -95,6 +97,11 @@ TrackInfoWindow::TrackInfoWindow(QSharedPointer<TrackItem> track, QWidget *paren
     this->connect(m_artistLabel, SIGNAL(linkActivated(QString)), this, SLOT(showUserChannel()));
     this->connect(m_track.data(), SIGNAL(favouriteChanged(bool)), this, SLOT(onFavouriteChanged(bool)));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_scrollArea, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_scrollArea, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     switch (m_track.data()->service()) {
     case Services::NoService:
         if (Settings::instance()->archiveOnline()) {
