@@ -75,6 +75,7 @@ void TransferItem::setPriority(Transfers::TransferPriority priority) {
 void TransferItem::setSize(qint64 size) {
     if (size != this->size()) {
         m_size = size;
+        m_track.data()->setSize(size);
         emit sizeChanged(size);
     }
 }
@@ -307,7 +308,6 @@ void TransferItem::onDownloadFinished() {
                     if (!m_playlistTracks.isEmpty()) {
                         qDebug() << "Download error: skipping track";
                         m_track = m_playlistTracks.takeFirst();
-                        this->setSize(m_track.data()->size());
                         this->setCurrentIndex(this->currentIndex() + 1);
                         this->startTransfer();
                     }
@@ -550,7 +550,6 @@ void TransferItem::moveDownloadedFiles() {
             }
             else {
                 m_track = m_playlistTracks.takeFirst();
-                this->setSize(m_track.data()->size());
                 this->setCurrentIndex(this->currentIndex() + 1);
 
                 switch(this->status()) {
