@@ -7,7 +7,6 @@ class UserListModel;
 class ListView;
 class QLabel;
 class QGridLayout;
-class QAction;
 class QModelIndex;
 class QUrl;
 
@@ -15,7 +14,7 @@ class UserListTab : public AbstractTab
 {
     Q_OBJECT
 public:
-    explicit UserListTab(const QString &userId, QWidget *parent = 0);
+    explicit UserListTab(QWidget *parent = 0);
     void setUserFeed(const QUrl &feed);
 
 private:
@@ -26,14 +25,10 @@ private slots:
     void onLoadingChanged(bool loading);
     void onCountChanged(int count);
     void onItemClicked(const QModelIndex &index);
-    void showUserChannel(const QString &userId);
-    void showFollowingTracks();
 
 private:
-    QString m_userId;
     UserListModel *m_model;
     ListView *m_listView;
-    QAction *m_tracksAction;
     QLabel *m_noResultsLabel;
     QGridLayout *m_grid;
 };
