@@ -1,8 +1,10 @@
 #include "userlistwindow.h"
 #include "channelwindow.h"
 #include "userlistdelegate.h"
-#include "../base/userlistmodel.h"
 #include "listview.h"
+#include "nowplayingbutton.h"
+#include "../base/userlistmodel.h"
+#include "../base/settings.h"
 #include <QLabel>
 #include <QMaemo5Style>
 
@@ -16,6 +18,7 @@ UserListWindow::UserListWindow(QWidget *parent) :
 
     m_listView->setModel(m_model);
     m_listView->setItemDelegate(new UserListDelegate(m_listView));
+    m_listView->setMonitorScrolling(true);
     m_noResultsLabel->hide();
 
     this->connect(m_model, SIGNAL(loadingChanged(bool)), this, SLOT(onLoadingChanged(bool)));
@@ -23,6 +26,11 @@ UserListWindow::UserListWindow(QWidget *parent) :
     this->connect(m_listView, SIGNAL(clicked(QModelIndex)), this, SLOT(onItemClicked(QModelIndex)));
     this->connect(m_listView, SIGNAL(atEnd()), m_model, SLOT(getMoreUsers()));
 
+    if (Settings::instance()->mediaPlayer() == "musikloud") {
+        this->connect(m_listView, SIGNAL(scrollingStarted()), NowPlayingButton::instance(), SLOT(hide()));
+        this->connect(m_listView, SIGNAL(scrollingStopped()), NowPlayingButton::instance(), SLOT(poke()));
+    }
+
     this->onOrientationChanged();
 }
 
