@@ -3,8 +3,6 @@
 #include <QPaintEvent>
 #include <QPainter>
 #include <QMaemo5Style>
-#include <QShowEvent>
-#include <QHideEvent>
 #include <QMouseEvent>
 
 WaveformLabel::WaveformLabel(QWidget *parent) :
@@ -12,16 +10,6 @@ WaveformLabel::WaveformLabel(QWidget *parent) :
 {
 }
 
-void WaveformLabel::showEvent(QShowEvent *event) {
-    this->connect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(update()));
-    event->accept();
-}
-
-void WaveformLabel::hideEvent(QHideEvent *event) {
-    this->disconnect(MediaPlayer::instance(), SIGNAL(positionChanged(qint64)), this, SLOT(update()));
-    event->accept();
-}
-
 void WaveformLabel::mousePressEvent(QMouseEvent *event) {
     m_pressed = true;
     event->accept();
